@@ -22,7 +22,7 @@
 
 from __future__ import with_statement
 
-VERSION = "0.8.0.1"
+VERSION = "0.8.0.4"
    
 
 import logging
@@ -135,13 +135,14 @@ class Core(gobject.GObject):
         'options_show_error': True,
         'options_show_html_description': False,
         'map_providers': [
-            ('OpenStreetMaps', {'remote_url': "http://128.40.168.104/mapnik/%(zoom)d/%(x)d/%(y)d.png", 'prefix': 'OpenStreetMap I'}),
+            ('OpenStreetMaps', {'remote_url': "http://tile.openstreetmap.org/mapnik/%(zoom)d/%(x)d/%(y)d.png", 'prefix': 'OpenStreetMap I'}),
             ('OpenCycleMaps', {'remote_url': 'http://andy.sandbox.cloudmade.com/tiles/cycle/%(zoom)d/%(x)d/%(y)d.png', 'prefix': 'OpenCycleMap'})
 
         ],
         'options_map_double_size': False,
         'options_rotate_screen': 0,
-        'tts_interval': 0
+        'tts_interval': 0,
+        'options_default_log_text' : 'TFTC!\n\nLogged at %X from my %(machine)s using AGTL.',
     }
             
     def __init__(self, guitype, root):
@@ -287,56 +288,74 @@ class Core(gobject.GObject):
 
     def try_update(self):
         from urllib import urlretrieve
+        from urllib2 import HTTPError
         import tempfile
         import hashlib
         from shutil import copyfile
         self.create_recursive(self.UPDATE_DIR)
         baseurl = 'http://www.danielfett.de/files/agtl-updates/%s' % VERSION
         url = "%s/updates" % baseurl
+        self.emit('progress', 0.5, "Checking for updates...")
         try:
-            reader = self.downloader.get_reader(url, login=False)
-        except Exception, e:
-            logging.exception(e)
-            raise Exception("No updates were found. (Could not download index file.)")
-
-        try:
-            files = []
-            for line in reader:
-                md5, name = line.strip().split('  ')
-                handle, temp = tempfile.mkstemp()
-                files.append((md5, name, temp))
-        except Exception, e:
-            logging.exception(e)
-            raise Exception("No updates were found. (Could not process index file.)")
-
-        if len(files) == 0:
-            raise Exception("There are no updates available.")
-
-        for md5sum, name, temp in files:
-            url = '%s/%s' % (baseurl, name)
             try:
-                urlretrieve(url, temp)
+                reader = self.downloader.get_reader(url, login=False)
+            except HTTPError, e:
+                logging.exception(e)
+                raise Exception("No updates available.")
             except Exception, e:
                 logging.exception(e)
-                raise Exception("Could not download file '%s'" % name)
+                raise Exception("Could not connect to update server.")
 
-            hash = hashlib.md5(open(temp).read()).hexdigest()
-            if hash != md5sum:
-                raise Exception("There was an error downloading the file. (MD5 sum mismatch in  %s)" % name)
-
-        for md5sum, name, temp in files:
-            file = path.join(self.UPDATE_DIR, name)
             try:
-                copyfile(temp, file)
+                files = []
+                for line in reader:
+                    md5, name = line.strip().split('  ')
+                    handle, temp = tempfile.mkstemp()
+                    files.append((md5, name, temp))
             except Exception, e:
                 logging.exception(e)
-                raise Exception("The update process was stopped while copying files. AGTL may run or not. If not, delete all *.py files in %s." % self.UPDATE_DIR)
-            finally:
+                raise Exception("No updates were found. (Could not process index file.)")
+
+            if len(files) == 0:
+                raise Exception("No updates available.")
+
+            for md5sum, name, temp in files:
+                url = '%s/%s' % (baseurl, name)
                 try:
-                    remove(tmpfile)
-                except Exception:
-                    pass
+                    urlretrieve(url, temp)
+                except Exception, e:
+                    logging.exception(e)
+                    raise Exception("Could not download file '%s'" % name)
 
+                hash = hashlib.md5(open(temp).read()).hexdigest()
+                if hash != md5sum:
+                    raise Exception("There was an error downloading the file. (MD5 sum mismatch in %s)" % name)
+
+            for md5sum, name, temp in files:
+                file = path.join(self.UPDATE_DIR, name)
+                try:
+                    copyfile(temp, file)
+                except Exception, e:
+                    logging.exception(e)
+                    raise Exception("The update process was stopped while copying files. AGTL may run or not. If not, delete all *.py files in %s." % self.UPDATE_DIR)
+                finally:
+                    try:
+                        remove(tmpfile)
+                    except Exception:
+                        pass
+        except Exception, e:
+            logging.exception(e)
+            def same_thread(error):
+                self.emit('hide-progress')
+                self.emit('error', error)
+                return False
+            gobject.idle_add(same_thread, e)
+            return None
+            
+        def same_thread():
+            self.emit('hide-progress')
+            return False
+        gobject.idle_add(same_thread)
         return self._install_updates()
 
 
@@ -636,10 +655,11 @@ class Core(gobject.GObject):
 
     # called on signal by downloading thread
     def on_download_error(self, something, error):
+        extra_message = "Please try the online update in the about menu. Error:\n%s" % error
         logging.exception(error)
         def same_thread(error):
             self.emit('hide-progress')
-            self.emit('error', error)
+            self.emit('error', extra_message)
             return False
         gobject.idle_add(same_thread, error)
 
